@@ -1,4 +1,5 @@
 import base64
+import logging
 from types import AsyncGeneratorType
 from typing import Union, Any, List, Set
 
@@ -17,6 +18,8 @@ from feedsearch_crawler.feed_spider.regexes import rss_regex
 from feedsearch_crawler.feed_spider.site_meta import SiteMeta
 from feedsearch_crawler.feed_spider.site_meta_parser import SiteMetaParser
 
+logger = logging.getLogger(__name__)
+
 
 class FeedsearchSpider(Crawler):
     duplicate_filter_class = NoQueryDupeFilter
@@ -65,7 +68,7 @@ class FeedsearchSpider(Crawler):
                 return
 
         if not isinstance(response.text, str):
-            self.logger.debug("No text in %s", response)
+            logger.debug("No text in %s", response)
             return
 
         yield self.parse_site_meta(request, response)
@@ -79,7 +82,7 @@ class FeedsearchSpider(Crawler):
 
         # Don't waste time trying to parse and follow urls if the max depth is already reached.
         if response.is_max_depth_reached(self.max_depth):
-            self.logger.debug("Max depth %d reached: %s", self.max_depth, response)
+            logger.debug("Max depth %d reached: %s", self.max_depth, response)
             return
 
         # Make sure the Response XML has been parsed if it exists.
@@ -92,7 +95,7 @@ class FeedsearchSpider(Crawler):
             return
 
         link_filter = LinkFilter(
-            self.logger, request=request, response=response, full_crawl=self.full_crawl
+            request=request, response=response, full_crawl=self.full_crawl
         )
 
         # Find all links in the Response.
@@ -221,12 +224,10 @@ class FeedsearchSpider(Crawler):
 
         try:
             if not is_png(response.data) and not is_ico(response.data):
-                self.logger.debug(
-                    "Response data is not a valid image type: %s", response
-                )
+                logger.debug("Response data is not a valid image type: %s", response)
                 return
         except Exception as e:
-            self.logger.exception("Failure validation image type: %s: %s", response, e)
+            logger.exception("Failure validation image type: %s: %s", response, e)
 
         try:
             encoded = base64.b64encode(response.data)
@@ -235,7 +236,7 @@ class FeedsearchSpider(Crawler):
             favicon.data_uri = uri
             self.add_favicon(favicon)
         except Exception as e:
-            self.logger.exception("Failure encoding image: %s: %s", response, e)
+            logger.exception("Failure encoding image: %s: %s", response, e)
 
     def create_start_urls(self, urls: List[Union[URL, str]]) -> List[URL]:
         """
@@ -249,7 +250,9 @@ class FeedsearchSpider(Crawler):
             if isinstance(url, str):
                 if "//" not in url:
                     url = f"//{url}"
-                url = parse_href_to_url(self.logger, url)
+                url = parse_href_to_url(url)
+                if not url:
+                    continue
 
             if url.scheme.lower() not in ["http", "https"]:
                 url = url.with_scheme("http")
